/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jbi.messaging.exchange.impl;

import java.net.URI;

import javax.jbi.messaging.MessageExchangeFactory;
import javax.jbi.messaging.MessagingException;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.ow2.petals.commons.Constants;
import org.ow2.petals.jbi.messaging.PetalsDeliveryChannel;
import org.ow2.petals.jbi.messaging.exchange.AbstractMessageExchangeFactory;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;
import org.ow2.petals.jbi.servicedesc.endpoint.Location;

import com.ebmwebsourcing.easycommons.uuid.QualifiedUUIDGenerator;

/**
 * A default implementation for the {@link MessageExchangeFactory} with factory methods to create instances of
 * {@link AbstractMessageExchangeFactory}.
 * 
 * @author vnoel
 *
 */
public class DefaultMessageExchangeFactory extends AbstractMessageExchangeFactory {

    protected static final QualifiedUUIDGenerator petalsQualifiedUUIDGenerator = new QualifiedUUIDGenerator(
            Constants.UUID_DOMAIN);

    private PetalsDeliveryChannel myChannel;

    protected DefaultMessageExchangeFactory(final ServiceEndpoint targetEndpoint, final QName targetInterface,
            final QName targetService, final PetalsDeliveryChannel myChannel) {
        super(targetEndpoint, targetInterface, targetService, myChannel.getLocation(), myChannel.getContext(),
                myChannel.getLogger());
        this.myChannel = myChannel;
    }

    @Override
    protected PetalsMessageExchange buildExchange(final URI pattern, final Location consumerLocation)
            throws MessagingException {

        if (!this.myChannel.isOpened()) {
            throw new MessagingException("The channel that created this MessageExchangeFactory is closed");
        }

        return new MessageExchangeImpl(petalsQualifiedUUIDGenerator.getNewID(), pattern, consumerLocation);
    }

    public static MessageExchangeFactory create(final PetalsDeliveryChannel myChannel) {
        return new DefaultMessageExchangeFactory(null, null, null, myChannel);
    }

    public static MessageExchangeFactory createForEndpoint(final PetalsDeliveryChannel myChannel,
            final ServiceEndpoint targetEndpoint) {
        return new DefaultMessageExchangeFactory(targetEndpoint, null, null, myChannel);
    }

    public static MessageExchangeFactory createForInterface(final PetalsDeliveryChannel myChannel,
            final QName targetInterface) {
        return new DefaultMessageExchangeFactory(null, targetInterface, null, myChannel);
    }

    public static MessageExchangeFactory createForService(final PetalsDeliveryChannel myChannel,
            final QName targetService) {
        return new DefaultMessageExchangeFactory(null, null, targetService, myChannel);
    }
}
