/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jbi.servicedesc.endpoint;

import java.io.Serializable;

/**
 * The location bean. 
 * <p>
 * Contains all the needed information to reach a service but
 * does NOT contains the endpoint itself!
 * </p>
 * 
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class Location implements Serializable {

    private static final long serialVersionUID = 6036195680156183050L;

    private final String containerName;

    private final String componentName;

    public Location(String containerName, String componentName) {
        this.containerName = containerName;
        this.componentName = componentName;
    }

    public String getContainerName() {
        return this.containerName;
    }

    public String getComponentName() {
        return this.componentName;
    }

    @Override
    public String toString() {
        return "Location[" + this.componentName + "@" + this.containerName + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result
                + ((this.componentName == null) ? 0 : this.componentName.hashCode());
        result = prime * result
                + ((this.containerName == null) ? 0 : this.containerName.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (this.getClass() != obj.getClass()) {
            return false;
        }
        Location other = (Location) obj;
        if (this.componentName == null) {
            if (other.componentName != null) {
                return false;
            }
        } else if (!this.componentName.equals(other.componentName)) {
            return false;
        }
        if (this.containerName == null) {
            if (other.containerName != null) {
                return false;
            }
        } else if (!this.containerName.equals(other.containerName)) {
            return false;
        }
        return true;
    }

}
