/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */

package org.ow2.petals.jbi.servicedesc.endpoint.impl;

import javax.xml.namespace.QName;

import org.ow2.petals.jbi.servicedesc.endpoint.Location;
import org.ow2.petals.jbi.servicedesc.endpoint.PetalsServiceEndpoint;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.Element;

import com.ebmwebsourcing.easycommons.xml.DocumentBuilders;

/**
 * A base implementation for the petals service endpoint.
 * 
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class JBIServiceEndpointImpl implements PetalsServiceEndpoint {

    private static final long serialVersionUID = 4487649085296224233L;

    private final String endpointName;

    private final QName serviceName;

    private final Location location;

    private final QName[] interfacesName;

    private final EndpointType type;

    public JBIServiceEndpointImpl(final EndpointType type, final String endpointName, final QName serviceName,
            final QName[] interfacesName, final Location location) {
        this.endpointName = endpointName;
        this.serviceName = serviceName;
        this.interfacesName = interfacesName.clone();
        this.location = location;
        this.type = type;
    }

    @Override
    public String getEndpointName() {
        return this.endpointName;
    }

    @Override
    public Location getLocation() {
        return this.location;
    }

    @Override
    public QName getServiceName() {
        return this.serviceName;
    }

    @Override
    public QName[] getInterfaces() {
        return this.interfacesName.clone();
    }

    @Override
    public String toString() {
        return this.type + " endpoint for " + this.serviceName + "(" + this.endpointName + ") on " + this.location;
    }

    @Override
    public EndpointType getType() {
        return this.type;
    }

    @Override
    public DocumentFragment getAsReference(final QName operationName) {
        final Document doc = DocumentBuilders.newDocument();
        final DocumentFragment result = doc.createDocumentFragment();
        final Element e = doc.createElementNS(JBI_NAMESPACE, EPR_NAME);
        e.setAttribute("xmlns:srvNs", this.getServiceName().getNamespaceURI());
        e.setAttribute(SERVICE_NAME, "srvNs:" + this.getServiceName().getLocalPart());
        e.setAttribute(ENDPOINT_NAME, this.getEndpointName());
        result.appendChild(e);
        return result;
    }
}
